@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import os
+import platform
 import sys
 import shutil
 import yaml
@@ -85,12 +86,14 @@ class SoBuilder(object):
 
 def build_docker():
 
+    isWindows = platform.system() == 'Windows'
+
     if not os.path.exists('requirements.txt'):
         print('错误： requirements.txt文件不存在！')
         return
-    
+
     try:
-        with open('./application.yml', 'r') as f:
+        with open('./application.yml', 'rb') as f:
             yml = yaml.load(f, Loader=yaml.SafeLoader)
     except:
         print('错误： 模型配置文件application.yml不存在！')
@@ -113,25 +116,39 @@ def build_docker():
         build_web = yml['build']['build_web']
     except:
         build_web = False
-        
+
     try:
         build_so = yml['build']['compile_python_to_so']
     except:
         build_so = False
-        
-    os.system('rm -rf temp')
-    os.system('mkdir temp')
-    os.system('cp ./application.yml ./temp')
-    os.system('cp ./requirements.txt ./temp')
-    os.system('cp ./Dockerfile ./temp')
+
+    if isWindows:
+        os.system('rd /s /q temp')
+        os.system('mkdir temp')
+        os.system('xcopy /q application.yml temp')
+        os.system('xcopy /q requirements.txt temp')
+        os.system('xcopy /q Dockerfile temp')
+    else:
+        os.system('rm -rf temp')
+        os.system('mkdir temp')
+        os.system('cp ./application.yml ./temp')
+        os.system('cp ./requirements.txt ./temp')
+        os.system('cp ./Dockerfile ./temp')
 
     if build_so:
         so_builder = SoBuilder('app')
         so_builder.build_so()
-        os.system('mv ./build/app ./temp/')
+        if isWindows:
+            os.system('move /y /q build\\app temp')
+        else:
+            os.system('mv ./build/app ./temp/')
         shutil.rmtree('build')
     else:
-        os.system('cp -rf ./app ./temp/')
+        if isWindows:
+            os.system('mkdir temp\\app')
+            os.system('xcopy /y /q /s /e app temp\\app')
+        else:
+            os.system('cp -rf ./app ./temp/')
 
     if build_web:
         if os.path.exists('./webapp/src'):
@@ -142,12 +159,19 @@ def build_docker():
             os.system('ng build --prod')
             os.chdir(cwd)
         if os.path.exists('./webapp/www'):
-            os.system('mkdir temp/webapp')
-            os.system('cp -rf ./webapp/www ./temp/webapp/')
+            if isWindows:
+                os.system('mkdir temp\\webapp\\www')
+                os.system('xcopy /y /q /s /e webapp\\www temp\\webapp\\www')
+            else:
+                os.system('mkdir temp/webapp')
+                os.system('cp -rf ./webapp/www ./temp/webapp/')
 
     os.system('docker image rm {}:{}'.format(image_name, image_tag))
     os.system('docker build -t {}:{} ./temp'.format(image_name, image_tag))
-    os.system('rm -rf temp')
+    if isWindows:
+        os.system('rd /s /q temp')
+    else:
+        os.system('rm -rf temp')
 
     print('模型docker镜像 {}:{} 构建完成！ '.format(image_name, image_tag))
 
