@@ -805,7 +805,7 @@ def start():
     logging.basicConfig(level=log_level, format='%(asctime)s - %(levelname)s - %(message)s')
 
     try:
-        with open('./application.yml', 'r') as f:
+        with open('./application.yml', 'rb') as f:
             yml = yaml.load(f, Loader=yaml.SafeLoader)
     except:
         logging.error('服务配置文件application.yml不存在！')
